@@ -2,8 +2,8 @@
 # Name: dev_tool.py                                                           #
 # Purpose: Provides logging and error tracking utilities                      #
 # Author: Cody Precord <cprecord@editra.org>                                  #
-# Copyright: (c) 2007 Cody Precord <staff@editra.org>                         #
-# Licence: wxWindows Licence                                                  #
+# Copyright: (c) 2008 Cody Precord <staff@editra.org>                         #
+# License: wxWindows License                                                  #
 ###############################################################################
 
 """ Editra Development Tools 
@@ -12,23 +12,29 @@
 
 """
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: dev_tool.py 51267 2008-01-18 07:47:43Z CJP $"
-__revision__ = "$Revision: 51267 $"
+__svnid__ = "$Id: dev_tool.py 51431 2008-01-29 07:46:49Z CJP $"
+__revision__ = "$Revision: 51431 $"
 
+#-----------------------------------------------------------------------------#
+# Imports
 import os
 import sys
 import re
 import platform
 import traceback
-import codecs
 import time
 import webbrowser
 import wx
+
+# Local Imports
 import ed_glob
 import ed_msg
 
+#-----------------------------------------------------------------------------#
+# Globals
 _ = wx.GetTranslation
 RE_LOG_LBL = re.compile(r"\[(.+?)\]")
+
 #-----------------------------------------------------------------------------#
 # General Debuging Helper Functions
 
@@ -103,19 +109,35 @@ class LogMsg:
         self._msg = dict(mstr=msg, msrc=msrc, lvl=level, tstamp=time.time())
         self._ok = True
 
+    def __eq__(self, other):
+        """Define the equal to operation"""
+        return self.TimeStamp == other.TimeStamp
+
+    def __ge__(self, other):
+        """Define the greater than or equal to operation"""
+        return self.TimeStamp >= other.TimeStamp
+
+    def __gt__(self, other):
+        """Define the greater than operation"""
+        return self.TimeStamp > other.TimeStamp
+
+    def __le__(self, other):
+        """Define the less than or equal to operation"""
+        return self.TimeStamp <= other.TimeStamp
+
+    def __lt__(self, other):
+        """Define the less than operation"""
+        return self.TimeStamp < other.TimeStamp
+
     def __repr__(self):
         """String representation of the object"""
         return '<LogMsg %s:%d>' % (self._msg['lvl'], self._msg['tstamp'])
 
     def __str__(self):
         """Returns a nice formatted string version of the message"""
-        ltime = time.localtime(self._msg['tstamp'])
-        tstamp = u"[%s:%s:%s]" % (str(ltime[3]).zfill(2),
-                                  str(ltime[4]).zfill(2),
-                                  str(ltime[5]).zfill(2))
         statement = unicode(self._msg['mstr'])
-        s_lst = [u"%s[%s][%s]%s" % (tstamp, self._msg['msrc'],
-                                    self._msg['lvl'], msg) 
+        s_lst = [u"[%s][%s][%s]%s" % (self.ClockTime, self._msg['msrc'],
+                                      self._msg['lvl'], msg) 
                  for msg in statement.split(u"\n")
                  if len(msg.strip())]
         out = os.linesep.join(s_lst)
@@ -125,6 +147,15 @@ class LogMsg:
 
         return out.encode('utf-8', 'replace')
 
+    @property
+    def ClockTime(self):
+        """Formatted timestring of the messages timestamp"""
+        ltime = time.localtime(self._msg['tstamp'])
+        tstamp = u"%s:%s:%s" % (str(ltime[3]).zfill(2),
+                                str(ltime[4]).zfill(2),
+                                str(ltime[5]).zfill(2))
+        return tstamp
+
     @property
     def Expired(self):
         """Has this message already been retrieved
@@ -218,17 +249,18 @@ def ExceptionHook(exctype, value, trace):
 
     """
     ftrace = FormatTrace(exctype, value, trace)
+
     # Ensure that error gets raised to console as well
     print ftrace
 
     # If abort has been set and we get here again do a more forcefull shutdown
-    global ABORT
-    if ABORT:
+    
+    if ErrorDialog.ABORT:
         os._exit(1)
 
     # Prevent multiple reporter dialogs from opening at once
-    global REPORTER_ACTIVE
-    if not REPORTER_ACTIVE and not ABORT:
+    
+    if not ErrorDialog.REPORTER_ACTIVE and not ErrorDialog.ABORT:
         ErrorDialog(ftrace)
 
 def FormatTrace(etype, value, trace):
@@ -310,20 +342,19 @@ class ErrorReporter(object):
 #-----------------------------------------------------------------------------#
 
 ID_SEND = wx.NewId()
-ABORT = False
-REPORTER_ACTIVE = False
 class ErrorDialog(wx.Dialog):
     """Dialog for showing errors and and notifying Editra.org should the
     user choose so.
 
     """
+    ABORT = False
+    REPORTER_ACTIVE = False
     def __init__(self, message):
         """Initialize the dialog
         @param message: Error message to display
 
         """
-        global REPORTER_ACTIVE
-        REPORTER_ACTIVE = True
+        ErrorDialog.REPORTER_ACTIVE = True
         wx.Dialog.__init__(self, None, title="Error/Crash Reporter", 
                            style=wx.DEFAULT_DIALOG_STYLE)
         
@@ -391,15 +422,14 @@ class ErrorDialog(wx.Dialog):
         if e_id == wx.ID_CLOSE:
             self.Close()
         elif e_id == ID_SEND:
-            msg = u"mailto:%s?subject=Error Report&body=%s"
-            addr = u"bugs@%s" % (ed_glob.HOME_PAGE.replace("http://", '', 1))
+            msg = "mailto:%s?subject=Error Report&body=%s"
+            addr = "bugs@%s" % (ed_glob.HOME_PAGE.replace("http://", '', 1))
             msg = msg % (addr, self.err_msg)
-            msg = msg.replace(u"'", u'')
+            msg = msg.replace("'", '')
             webbrowser.open(msg)
             self.Close()
         elif e_id == wx.ID_ABORT:
-            global ABORT
-            ABORT = True
+            ErrorDialog.ABORT = True
             # Try a nice shutdown first time through
             wx.CallLater(500, wx.GetApp().OnExit, 
                          wx.MenuEvent(wx.wxEVT_MENU_OPEN, ed_glob.ID_EXIT),
@@ -413,6 +443,6 @@ class ErrorDialog(wx.Dialog):
         @param evt: Event that called this handler
 
         """
-        REPORTER_ACTIVE = False
+        ErrorDialog.REPORTER_ACTIVE = False
         self.Destroy()
         evt.Skip()
