@@ -21,8 +21,8 @@
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_glob.py 51248 2008-01-16 13:32:31Z CJP $"
-__revision__ = "$Revision: 51248 $"
+__svnid__ = "$Id: ed_glob.py 51394 2008-01-27 04:09:59Z CJP $"
+__revision__ = "$Revision: 51394 $"
 
 __all__ = [ 'CONFIG', 'SB_INFO', 'VERSION', 'PROG_NAME', 'ID_NEW', 'ID_OPEN', 
             'ID_CLOSE', 'ID_CLOSEALL', 'ID_SAVE', 'ID_SAVEAS', 'ID_SAVEALL', 
@@ -59,6 +59,11 @@ from info import *
 #---- Imported Libs/Objects ----#
 import wx
 
+#---- WX Compatibility Hacks ----#
+# GetText is not available in 2.9 but GetItemLabel is not available pre 2.8.6
+if wx.VERSION < (2, 8, 6, 0, ''):
+    wx.MenuItem.GetItemLabel = wx.MenuItem.GetText
+
 #---- Configuration Locations ----#
 # Values set when main loads
 CONFIG = {
@@ -127,9 +132,11 @@ ID_PREF          = wx.ID_PREFERENCES
 ID_PREF_LANG     = wx.NewId()
 ID_PREF_AALIAS   = wx.NewId()
 ID_PREF_CHKMOD   = wx.NewId()
+ID_PREF_DLEXER   = wx.NewId()
 ID_PREF_EDGE     = wx.NewId()
 ID_PREF_SYNTHEME = wx.NewId()
 ID_PREF_TABS     = wx.NewId()
+ID_PREF_UNINDENT = wx.NewId()
 ID_PREF_TABW     = wx.NewId()
 ID_PREF_FHIST    = wx.NewId()
 ID_PREF_WSIZE    = wx.NewId()
@@ -225,6 +232,7 @@ ID_FOLDER            = wx.NewId()
 ID_HARDDISK          = wx.NewId()
 ID_PACKAGE           = wx.NewId()
 ID_REPORTER          = wx.NewId()
+ID_STOP              = wx.ID_STOP
 ID_THEME             = wx.NewId()
 ID_USB               = wx.NewId()
 ID_UP                = wx.ID_UP
@@ -255,8 +263,10 @@ ID_2_PROF = {
              ID_PREF_LANG         : 'LANG',
              ID_REPORTER          : 'REPORTER',
              ID_SYNTAX            : 'SYNTAX',
+             ID_PREF_DLEXER       : 'DEFAULT_LEX',
              ID_PREF_SYNTHEME     : 'SYNTHEME',
              ID_PREF_TABS         : 'USETABS',
+             ID_PREF_UNINDENT     : 'BSUNINDENT',
              ID_PREF_TABW         : 'TABWIDTH',
              ID_SESSION           : 'SAVE_SESSION',
              ID_SHOW_EDGE         : 'SHOW_EDGE',
