@@ -2,8 +2,8 @@
 # Name: ed_main.py                                                            #
 # Purpose: Editra's Main Window                                               #
 # Author: Cody Precord <cprecord@editra.org>                                  #
-# Copyright: (c) 2007 Cody Precord <staff@editra.org>                         #
-# Licence: wxWindows Licence                                                  #
+# Copyright: (c) 2008 Cody Precord <staff@editra.org>                         #
+# License: wxWindows License                                                  #
 ###############################################################################
 
 """
@@ -21,8 +21,8 @@
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_main.py 51096 2008-01-08 08:03:46Z CJP $"
-__revision__ = "$Revision: 51096 $"
+__svnid__ = "$Id: ed_main.py 51588 2008-02-08 07:58:20Z CJP $"
+__revision__ = "$Revision: 51588 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -41,6 +41,7 @@ import ed_pages
 import ed_menu
 import ed_print
 import ed_cmdbar
+import ed_mdlg
 import syntax.syntax as syntax
 import generator
 import plugin
@@ -92,7 +93,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
 
         #---- Status bar on bottom of window ----#
         self.CreateStatusBar(3, style=wx.ST_SIZEGRIP)
-        self.SetStatusWidths([-1, 120, 155])
+        self.SetStatusWidths([-1, 90, 155])
         #---- End Statusbar Setup ----#
 
         #---- Notebook that contains the editting buffers ----#
@@ -257,6 +258,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         self._handlers['ui'].extend(addons.GetEventHandlers(ui_evt=True))
         self._shelf = iface.Shelf(plgmgr)
         self._shelf.Init(self)
+        self._handlers['ui'].extend(self._shelf.GetUiHandlers())
         self.LOG("[ed_main][info] Loading Generator plugins")
         generator.Generator(plgmgr).InstallMenu(menbar.GetMenuByName("tools"))
 
@@ -330,31 +332,29 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
             e_id = evt
 
         if e_id == ID_OPEN:
-            dlg = wx.FileDialog(self, _("Choose a File"), '', "", 
-                                ''.join(syntax.GenFileFilters()), 
+            fdir = self.GetNotebook().GetCurrentCtrl().GetFileName()
+            if len(fdir):
+                fdir = os.path.dirname(fdir)
+
+            dlg = wx.FileDialog(self, _("Choose a File"), fdir, "",
+                                ''.join(syntax.GenFileFilters()),
                                 wx.OPEN | wx.MULTIPLE)
             dlg.SetFilterIndex(_PGET('FFILTER', 'int', 0))
 
-            if dlg.ShowModal() != wx.ID_OK:
-                self.LOG('[ed_main][info] Canceled Opening File')
-            else:
+            if dlg.ShowModal() == wx.ID_OK:
                 _PSET('FFILTER', dlg.GetFilterIndex())
-                paths = dlg.GetPaths()
-                for path in paths:
+                for path in dlg.GetPaths():
                     if _PGET('OPEN_NW', default=False):
                         wx.GetApp().OpenNewWindow(path)
                     else:
-                        dirname = util.GetPathName(path)
-                        filename = util.GetFileName(path)
-                        self.nb.OpenPage(dirname, filename)   
+                        self.nb.OpenPage(util.GetPathName(path),
+                                         util.GetFileName(path))   
                         self.nb.GoCurrentPage()
 
             dlg.Destroy()
         else:
             self.LOG("[ed_main][info] CMD Open File: %s" % fname)
-            filename = util.GetFileName(fname)
-            dirname = util.GetPathName(fname)
-            self.nb.OpenPage(dirname, filename)
+            self.nb.OpenPage(util.GetPathName(fname), util.GetFileName(fname))
 
     def GetFrameManager(self):
         """Returns the manager for this frame
@@ -434,13 +434,13 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
 
         """
         fnum = evt.GetId() - wx.ID_FILE1
-        file_h = self.filehistory.GetHistoryFile(fnum)
+        fname = self.filehistory.GetHistoryFile(fnum)
 
         # Check if file still exists
-        if not os.path.exists(file_h):
+        if not os.path.exists(fname):
             mdlg = wx.MessageDialog(self, _("%s could not be found\nPerhaps "
                                             "its been moved or deleted") % \
-                                    file_h, _("File Not Found"),
+                                    fname, _("File Not Found"),
                                     wx.OK | wx.ICON_WARNING)
             mdlg.CenterOnParent()
             mdlg.ShowModal()
@@ -448,7 +448,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
             # Remove offending file from history
             self.filehistory.RemoveFileFromHistory(fnum)
         else:
-            self.DoOpen(evt, file_h)
+            self.DoOpen(evt, fname)
 
     def OnClosePage(self, evt):
         """Close a page
@@ -460,8 +460,6 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         if e_id == ID_CLOSE:
             self.nb.ClosePage()
         elif e_id == ID_CLOSEALL:
-            # TODO maybe warn and ask if they really want to close
-            #      all pages before doing it.
             self.nb.CloseAllPages()
         else:
             evt.Skip()
@@ -495,26 +493,23 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
                 if result:
                     self.PushStatusText(_("Saved File: %s") % fname, SB_INFO)
                 else:
-                    self.PushStatusText(_("ERROR: Failed to save %s") % fname, SB_INFO)
-                    dlg = wx.MessageDialog(self, 
-                                           _("Failed to save file: %s\n\nError:\n%d") % \
-                                             (fname, result), _("Save Error"),
-                                            wx.OK | wx.ICON_ERROR)
-                    dlg.ShowModal()
-                    dlg.Destroy()
+                    err = ctrl[1].GetDocPointer().GetLastError()
+                    self.PushStatusText(_("ERROR: %s") % err, SB_INFO)
+                    ed_mdlg.SaveErrorDlg(self, fname, err)
+                    ctrl[1].GetDocPointer().ClearLastError()
             else:
                 ret_val = self.OnSaveAs(ID_SAVEAS, ctrl[0], ctrl[1])
                 if ret_val:
                     self.AddFileToHistory(ctrl[1].GetFileName())
 
-    def OnSaveAs(self, evt, title=u'', page=None):
+    def OnSaveAs(self, evt, title='', page=None):
         """Save File Using a new/different name
         @param evt: Event fired that called this handler
         @type evt: wxMenuEvent
 
         """
-        dlg = wx.FileDialog(self, _("Choose a Save Location"), u'', 
-                            title.lstrip(u"*"), 
+        dlg = wx.FileDialog(self, _("Choose a Save Location"), '', 
+                            title.lstrip("*"), 
                             ''.join(syntax.GenFileFilters()), 
                             wx.SAVE | wx.OVERWRITE_PROMPT)
 
@@ -530,15 +525,13 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
             result = ctrl.SaveFile(path)
             fname = util.GetFileName(ctrl.GetFileName())
             if not result:
-                dlg = wx.MessageDialog(self, _("Failed to save file: %s\n\nError:\n%d") % \
-                                       (fname, result), _("Save Error"),
-                                       wx.OK | wx.ICON_ERROR)
-                dlg.ShowModal()
-                dlg.Destroy()
+                err = ctrl.GetDocPointer().GetLastError()
+                ed_mdlg.SaveErrorDlg(self, fname, err)
+                ctrl.GetDocPointer().ClearLastError()
                 self.PushStatusText(_("ERROR: Failed to save %s") % fname, SB_INFO)
             else:
                 self.PushStatusText(_("Saved File As: %s") % fname, SB_INFO)
-                self.SetTitle(u"%s - file://%s" % (fname, ctrl.GetFileName()))
+                self.SetTitle("%s - file://%s" % (fname, ctrl.GetFileName()))
                 self.nb.SetPageText(self.nb.GetSelection(), fname)
                 self.nb.GetCurrentCtrl().FindLexer()
                 self.nb.UpdatePageImage()
@@ -558,8 +551,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
                                _("Profile") + " (*.ppb)|*.ppb", 
                                 wx.SAVE | wx.OVERWRITE_PROMPT)
 
-            result = dlg.ShowModal()
-            if result == wx.ID_OK:
+            if dlg.ShowModal() == wx.ID_OK:
                 profiler.Profile().Write(dlg.GetPath())
                 self.PushStatusText(_("Profile Saved as: %s") % \
                                     dlg.GetFilename(), SB_INFO)
@@ -605,8 +597,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         showing print previews, and opening the printer settings
         dialog.
         @todo: is any manual cleanup required for the printer objects?
-        @param evt: Event fired that called this handler
-        @type evt: wxMenuEvent
+        @param evt: wxMenuEvent
 
         """
         e_id = evt.GetId()
@@ -676,8 +667,15 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         #     into account so destroy it so that the window size is accurate.
         if wx.Platform == '__WXMAC__' and self.GetToolBar():
             self.GetToolBar().Destroy()
+
+        # Raise the window from being iconized so that the size and position is
+        # correct for the next launch (msw).
+        if self.IsIconized():
+            self.Iconize(False)
+
         _PSET('WSIZE', self.GetSizeTuple())
         _PSET('WPOS', self.GetPositionTuple())
+
         self.LOG("[ed_main][evt] OnClose: Closing editor at pos=%s size=%s" % \
                  (_PGET('WPOS', 'str'), _PGET('WSIZE', 'str')))
         
@@ -889,7 +887,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         e_id = evt.GetId()
         evt.SetMode(wx.UPDATE_UI_PROCESS_SPECIFIED)
         # Slow the update interval to reduce overhead
-        evt.SetUpdateInterval(200)
+        evt.SetUpdateInterval(160)
         ctrl = self.nb.GetCurrentCtrl()
         if e_id == ID_UNDO:
             evt.Enable(ctrl.CanUndo())
@@ -912,7 +910,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
 
         e_id = evt.GetId()
         evt.SetMode(wx.UPDATE_UI_PROCESS_SPECIFIED)
-        evt.SetUpdateInterval(350)
+        evt.SetUpdateInterval(300)
         ctrl = self.nb.GetCurrentCtrl()
         eol = ctrl.GetEOLModeId()
         if e_id == ID_USE_SOFTTABS:
@@ -1059,7 +1057,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         """
         name = "%s v%s" % (PROG_NAME, VERSION)
         if len(title):
-            name = u' - ' + name
+            name = " - " + name
         wx.Frame.SetTitle(self, title + name)
 
 
@@ -1106,7 +1104,7 @@ def OnHelp(evt):
     elif e_id == ID_DOCUMENTATION:
         webbrowser.open(HOME_PAGE + "/?page=doc", 1)
     elif e_id == ID_CONTACT:
-        webbrowser.open(u'mailto:%s' % CONTACT_MAIL)
+        webbrowser.open("mailto:%s" % CONTACT_MAIL)
     else:
         evt.Skip()
 
@@ -1132,12 +1130,10 @@ def OnPreferences(evt):
 
 #-----------------------------------------------------------------------------#
 # Plugin interface to the MainWindow
-# For backwards compatibility soon to be removed
-MainWindowI = iface.MainWindowI
 
 class MainWindowAddOn(plugin.Plugin):
     """Plugin that Extends the L{MainWindowI}"""
-    observers = plugin.ExtensionPoint(MainWindowI)
+    observers = plugin.ExtensionPoint(iface.MainWindowI)
     def Init(self, window):
         """Call all observers once to initialize
         @param window: window that observers become children of
