@@ -2,8 +2,8 @@
 # Name: ed_menu.py                                                            #
 # Purpose: Editra's Menubar and Menu related classes                          #
 # Author: Cody Precord <cprecord@editra.org>                                  #
-# Copyright: (c) 2007 Cody Precord <staff@editra.org>                         #
-# Licence: wxWindows Licence                                                  #
+# Copyright: (c) 2008 Cody Precord <staff@editra.org>                         #
+# License: wxWindows License                                                  #
 ###############################################################################
 
 """
@@ -19,8 +19,8 @@
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_menu.py 51110 2008-01-08 15:03:38Z CJP $"
-__revision__ = "$Revision: 51110 $"
+__svnid__ = "$Id: ed_menu.py 51569 2008-02-06 12:00:49Z CJP $"
+__revision__ = "$Revision: 51569 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -147,6 +147,7 @@ class EdMenu(wx.Menu):
             mitem = self.FindItemByPosition(item)
             if mitem.IsSeparator():
                 continue
+
             mlabel = mitem.GetItemLabel()
             if after and mitem.GetId() == after:
                 start = True
@@ -200,7 +201,7 @@ class EdMenu(wx.Menu):
 class EdMenuBar(wx.MenuBar):
     """Custom menubar to allow for easier access and updating
     of menu components.
-    @todo: this is currently a static object needs lots of refactoring
+    @todo: redo all of this
     
     """
     def __init__(self, style=0):
@@ -370,10 +371,19 @@ class EdMenuBar(wx.MenuBar):
         viewmenu.AppendSeparator()
         viewmenu.Append(ed_glob.ID_GOTO_LINE, _("Goto Line") + u"\tCtrl+G",
                             _("Goto Line Number"))
+
+        # Use ALT on win/gtk so the jump to word command doesn't get overridden
+        if wx.Platform == '__WXMAC__':
+            shortn = "\tCtrl+Right"
+            shortp = "\tCtrl+Left"
+        else:
+            shortn = "\tAlt+Right"
+            shortp = "\tAlt+Left"
+
         viewmenu.Append(ed_glob.ID_NEXT_MARK, _("Next Bookmark") + \
-                        u"\tCtrl+Right", _("View Line of Next Bookmark"))
+                        shortn, _("View Line of Next Bookmark"))
         viewmenu.Append(ed_glob.ID_PRE_MARK, _("Previous Bookmark") + \
-                        u"\tCtrl+Left", _("View Line of Previous Bookmark"))
+                        shortp, _("View Line of Previous Bookmark"))
         viewmenu.AppendSeparator()
         viewmenu.Append(ed_glob.ID_VIEW_TOOL, _("Toolbar"), 
                              _("Show Toolbar"), wx.ITEM_CHECK)
