@@ -2,8 +2,8 @@
 # Name: ed_pages.py                                                           #
 # Purpose: The main editor notebook                                           #
 # Author: Cody Precord <cprecord@editra.org>                                  #
-# Copyright: (c) 2007 Cody Precord <staff@editra.org>                         #
-# Licence: wxWindows Licence                                                  #
+# Copyright: (c) 2008 Cody Precord <staff@editra.org>                         #
+# License: wxWindows License                                                  #
 ###############################################################################
 
 """
@@ -25,8 +25,8 @@
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_pages.py 51129 2008-01-09 13:24:59Z CJP $"
-__revision__ = "$Revision: 51129 $"
+__svnid__ = "$Id: ed_pages.py 51601 2008-02-08 14:02:44Z CJP $"
+__revision__ = "$Revision: 51601 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -37,11 +37,14 @@ import ed_glob
 from profiler import Profile_Get
 import ed_stc
 import syntax.synglob as synglob
+import syntax.syntax as syntax
 import ed_search
 import util
 import doctools
 from extern import flatnotebook as FNB
 import ed_msg
+import ed_txt
+import ed_mdlg
 
 #--------------------------------------------------------------------------#
 # Globals
@@ -77,6 +80,7 @@ class EdPages(FNB.FlatNotebook):
         self.control = None
         self.frame = self.GetTopLevelParent() # MainWindow
         self._index = dict()          # image list index
+        self._ses_load = False
 
         # Set Additional Style Parameters
         self.SetNonActiveTabTextColour(wx.Colour(102, 102, 102))
@@ -97,6 +101,7 @@ class EdPages(FNB.FlatNotebook):
         self.Bind(wx.stc.EVT_STC_MODIFIED, self.OnUpdatePageText)
         self._pages.Bind(wx.EVT_LEFT_UP, self.OnLeftUp)
         self.Bind(wx.EVT_IDLE, self.OnIdle)
+        ed_msg.Subscribe(self.OnThemeChanged, ed_msg.EDMSG_THEME_CHANGED)
 
         # Add a blank page
         self.NewPage()
@@ -128,7 +133,6 @@ class EdPages(FNB.FlatNotebook):
                     ctrl = self.GetPage(page)
                     if path == ctrl.GetFileName():
                         self.SetSelection(page)
-                        self.ChangePage(page)
                         break
         elif os.path.exists(path) and not os.path.isfile(path):
             result = wx.ID_NO
@@ -167,12 +171,14 @@ class EdPages(FNB.FlatNotebook):
                         single blank page is opened.
 
         """
+        self._ses_load = True
         files = Profile_Get('LAST_SESSION')
         if files is not None:
             for fname in files:
                 if os.path.exists(fname) and os.access(fname, os.R_OK):
                     self.OpenPage(os.path.dirname(fname), 
                                   os.path.basename(fname))
+        self._ses_load = False
 
         if self.GetPageCount() == 0:
             self.NewPage()
@@ -185,11 +191,24 @@ class EdPages(FNB.FlatNotebook):
         self.GetTopLevelParent().Freeze()
         self.pg_num += 1
         self.control = ed_stc.EditraStc(self, wx.ID_ANY)
-        self.LOG("[ed_pages][evt] Page Creation ID: %d" % self.control.GetId())
+        self.LOG("[ed_pages][evt] New Page Created ID: %d" % self.control.GetId())
         self.AddPage(self.control, u"Untitled - %d" % self.pg_num)
         self.SetPageImage(self.GetSelection(), str(self.control.GetLangId()))
+
+        # Set the control up the the preferred default lexer
+        dlexer = Profile_Get('DEFAULT_LEX', 'str', 'Plain Text')
+        ext_reg = syntax.ExtensionRegister()
+        ext_lst = ext_reg.get(dlexer, ['txt', ])
+        self.control.FindLexer(ext_lst[0])
         self.GetTopLevelParent().Thaw()
 
+    def OnThemeChanged(self, msg):
+        """Update icons when the theme has changed
+        @param msg: Message Object
+
+        """
+        self.UpdateAllImages()
+
     def OpenPage(self, path, filename):
         """Open a File Inside of a New Page
         @param path: files base path
@@ -212,28 +231,27 @@ class EdPages(FNB.FlatNotebook):
                 control.Hide()
             else:
                 new_pg = False
+                control = self.control
         else:
             control = ed_stc.EditraStc(self, wx.ID_ANY)
             control.Hide()
 
         # Open file and get contents
-        err = False
-        in_txt = u''
-        enc = u'utf-8'
         if os.path.exists(path2file):
             try:
-                in_txt, enc = util.GetDecodedText(path2file)
-            except (UnicodeDecodeError, IOError, OSError), msg:
-                self.LOG(("[ed_pages][err] Failed to open file %s\n"
-                          "[ed_pages][err] %s") % (path2file, msg))
+                result = control.LoadFile(path2file)
+            except Exception, msg:
+                self.LOG("[ed_pages][err] Failed to open file %s\n" % path2file)
+                self.LOG("[ed_pages][err] %s" % msg)
 
                 # File could not be opened/read give up
-                err = wx.MessageDialog(self, _("Editra could not properly "
-                                               "open %s\n") \
-                                       % path2file, _("Error Opening File"),
-                                       style=wx.OK | wx.CENTER | wx.ICON_ERROR)
-                err.ShowModal()
-                err.Destroy()
+                # Don't raise a dialog during a session load error as if the
+                # dialog is shown before the mainwindow is ready it can cause
+                # the app to freeze.
+                if not self._ses_load:
+                    ed_mdlg.OpenErrorDlg(self, path2file, msg)
+                control.GetDocPointer().ClearLastError()
+                control.SetFileName('') # Reset the file name
 
                 if new_pg:
                     control.Destroy()
@@ -241,14 +259,41 @@ class EdPages(FNB.FlatNotebook):
                 self.GetTopLevelParent().Thaw()
                 return
 
+        # Check if there was encoding errors
+        if not result:
+            doc = control.GetDocPointer()
+            doc.ClearLastError()
+            enc = doc.GetEncoding()
+            enc1 = doc.GetMagic()
+            if enc1 is None:
+                enc1 = ed_txt.DEFAULT_ENCODING
+
+            if not self._ses_load:
+                dlg = wx.MessageDialog(self,
+                                       _("The document could not be decoded with %s."
+                                         "\n\nWould you like to open it as %s instead?")
+                                       % (enc1, enc), _("Encoding Error"),
+                                       style=wx.YES_NO|wx.ICON_WARNING)
+                dlg.CenterOnParent()
+                result = dlg.ShowModal()
+
+        if result == wx.ID_NO or not result:
+            if new_pg:
+                control.Destroy()
+            else:
+                control.SetText('')
+                control.SetDocPointer(ed_txt.EdFile())
+                control.SetSavePoint()
+
+            self.GetTopLevelParent().Thaw()
+            return
+            
         # Put control into page an place page in notebook
         if new_pg:
             control.Show()
             self.control = control
 
         # Pass directory and file name info to control object to save reference
-        self.control.SetText(in_txt, enc)
-        self.control.SetFileName(path2file)
         self.control.SetModTime(util.GetFileModTime(path2file))
         self.frame.AddFileToHistory(path2file)
         if new_pg:
@@ -257,7 +302,7 @@ class EdPages(FNB.FlatNotebook):
         self.frame.SetTitle("%s - file://%s" % (filename, 
                                                 self.control.GetFileName()))
         self.SetPageText(self.GetSelection(), filename)
-        self.LOG("[ed_pages][evt] Opened Page: ID = %d" % self.GetSelection())
+        self.LOG("[ed_pages][evt] Opened Page: %s" % filename)
 
         # Setup Document
         self.control.FindLexer()
@@ -273,6 +318,7 @@ class EdPages(FNB.FlatNotebook):
         # Refocus on selected page
         self.GoCurrentPage()
         self.GetTopLevelParent().Thaw()
+        ed_msg.PostMessage(ed_msg.EDMSG_FILE_OPENED, self.control.GetFileName())
 
     def GoCurrentPage(self):
         """Move Focus to Currently Selected Page.
@@ -347,6 +393,7 @@ class EdPages(FNB.FlatNotebook):
             elif os.path.isdir(fname):
                 dcnt = glob.glob(os.path.join(fname, '*'))
                 dcnt = util.FilterFiles(dcnt)
+                dlg = None
                 if not len(dcnt):
                     dlg = wx.MessageDialog(self, 
                                            _("There are no files that Editra"
@@ -354,7 +401,8 @@ class EdPages(FNB.FlatNotebook):
                                            _("No Valid Files to Open"),
                                            style=wx.OK | wx.CENTER | \
                                                  wx.ICON_INFORMATION)
-                else:
+                elif len(dcnt) > 5:
+                    # Warn when the folder contains many files
                     dlg = wx.MessageDialog(self, 
                                            _("Do you wish to open all %d files"
                                              " in this directory?\n\nWarning"
@@ -364,8 +412,12 @@ class EdPages(FNB.FlatNotebook):
                                            _("Open Directory?"),
                                            style=wx.YES | wx.NO | \
                                                  wx.ICON_INFORMATION)
-                result = dlg.ShowModal()
-                dlg.Destroy()
+                if dlg is not None:
+                    result = dlg.ShowModal()
+                    dlg.Destroy()
+                else:
+                    result = wx.ID_YES
+
                 if result == wx.ID_YES:
                     valid_files.extend(dcnt)
                 else:
@@ -457,10 +509,10 @@ class EdPages(FNB.FlatNotebook):
         """
         cpage = evt.GetSelection()
         self.ChangePage(cpage)
+        evt.Skip()
         self.LOG("[ed_pages][evt] Page Changed to %d" % cpage)
         self.LOG("[ed_pages][info] It has file named: %s" % \
                  self.control.GetFileName())
-        evt.Skip()
         ed_msg.PostMessage(ed_msg.EDMSG_UI_NB_CHANGED, (self, cpage))
 
     def OnPageClosing(self, evt):
@@ -484,8 +536,8 @@ class EdPages(FNB.FlatNotebook):
 
         """
         cpage = self.GetSelection()
-        self.LOG("[ed_pages][evt] Closed Page: #%d" % cpage)
         evt.Skip()
+        self.LOG("[ed_pages][evt] Closed Page: #%d" % cpage)
         ed_msg.PostMessage(ed_msg.EDMSG_UI_NB_CLOSED, (self, cpage))
 
     #---- End Event Handlers ----#
@@ -498,7 +550,6 @@ class EdPages(FNB.FlatNotebook):
         for page in xrange(self.GetPageCount()):
             result = self.ClosePage()
             if result == wx.ID_CANCEL:
-                self.LOG("[ed_pages][info] Canceled on page %d" % page)
                 break
             
     def ClosePage(self):
@@ -548,6 +599,14 @@ class EdPages(FNB.FlatNotebook):
                                               GetBitmap(lang_id, wx.ART_MENU))
         FNB.FlatNotebook.SetPageImage(self, pg_num, self._index[lang_id])
 
+    def SetSelection(self, pgnum):
+        """Set the currently selected page
+        @param pgnum: page number index
+
+        """
+        FNB.FlatNotebook.SetSelection(self, pgnum)
+        self.ChangePage(pgnum)
+
     def UpdateAllImages(self):
         """Reload and Reset all images in the notebook pages and
         the corresponding imagelist to match those of the current theme
@@ -570,11 +629,7 @@ class EdPages(FNB.FlatNotebook):
         @postcondition: page image is updated to reflect any changes in ctrl
 
         """
-        pg_num = self.GetSelection()
-        ftype = util.GetExtension(self.control.GetFileName())
-        ftype = ftype[-1].upper()
-        self.LOG("[ed_pages][info] Updating Page Image: Page %d" % pg_num)
-        self.SetPageImage(pg_num, str(self.control.GetLangId()))
+        self.SetPageImage(self.GetSelection(), str(self.control.GetLangId()))
 
     def OnUpdatePageText(self, evt):
         """Update the title text of the current page
@@ -595,7 +650,7 @@ class EdPages(FNB.FlatNotebook):
         except wx.PyDeadObjectError:
             pass
         
-    def UpdateTextControls(self):
+    def UpdateTextControls(self, meth=None, args=list()):
         """Updates all text controls to use any new settings that have
         been changed since initialization.
         @postcondition: all stc controls in the notebook are reconfigured
@@ -603,8 +658,11 @@ class EdPages(FNB.FlatNotebook):
 
         """
         for control in self.GetTextControls():
-            control.UpdateAllStyles()
-            control.Configure()
+            if meth is not None:
+                getattr(control, meth)(*args)
+            else:
+                control.UpdateAllStyles()
+                control.Configure()
 
 #---- End Function Definitions ----#
 
@@ -627,7 +685,7 @@ def PromptToReSave(win, cfile):
     result = mdlg.ShowModal()
     mdlg.Destroy()
     if result == wx.ID_YES:
-        win.control.SaveFile(cfile)
+        result = win.control.SaveFile(cfile)
     else:
         win.control.SetModTime(0)
 
