@@ -23,8 +23,8 @@
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_style.py 51096 2008-01-08 08:03:46Z CJP $"
-__revision__ = "$Revision: 51096 $"
+__svnid__ = "$Id: ed_style.py 51294 2008-01-20 01:56:01Z CJP $"
+__revision__ = "$Revision: 51294 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -37,6 +37,10 @@ from profiler import Profile_Get, Profile_Set
 # Globals
 STY_ATTRIBUTES     = u"face fore back size"
 STY_EX_ATTRIBUTES  = u"eol bold italic underline"
+
+# Parser Values
+RE_ESS_COMMENT = re.compile("\/\*[^*]*\*+([^/][^*]*\*+)*\/")
+
 #--------------------------------------------------------------------------#
 
 class StyleItem(object):
@@ -566,6 +570,9 @@ class StyleMgr(object):
                  data.
 
         """
+        # Remove all comments
+        style_data = RE_ESS_COMMENT.sub(u'', style_data)
+
         # Compact data into a contiguous string
         style_data = style_data.replace(u"\r\n", u"").replace(u"\n", u"")
         style_data = style_data.replace(u"\t", u"")
