@@ -21,8 +21,8 @@
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_theme.py 50641 2007-12-11 13:54:48Z CJP $"
-__revision__ = "$Revision: 50641 $"
+__svnid__ = "$Id: ed_theme.py 51397 2008-01-27 07:24:10Z CJP $"
+__revision__ = "$Revision: 51397 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -192,6 +192,7 @@ ART = { ed_glob.ID_ABOUT  : u'about.png',
         ed_glob.ID_SAVE    : u'save.png',
         ed_glob.ID_SAVEALL : u'saveall.png',
         ed_glob.ID_SAVEAS  : u'saveas.png',
+        ed_glob.ID_STOP    : u'stop.png',
         ed_glob.ID_STYLE_EDIT : u'style_edit.png',
         ed_glob.ID_TEX_GEN : u'tex_gen.png',
         ed_glob.ID_THEME  : u'theme.png',
@@ -223,6 +224,7 @@ MIME_ART = { synglob.ID_LANG_ADA : u'ada.png',
              synglob.ID_LANG_PASCAL : u'pascal.png',
              synglob.ID_LANG_PERL : u'perl.png',
              synglob.ID_LANG_PHP : u'php.png',
+             synglob.ID_LANG_PS : u'postscript.png',
              synglob.ID_LANG_PYTHON : u'python.png',
              synglob.ID_LANG_RUBY : u'ruby.png',
              synglob.ID_LANG_TCL : u'tcl.png',
