@@ -2,17 +2,17 @@
 # Name: ed_projinfo.py                                                        #
 # Purpose: Global project information                                         #
 # Author: Cody Precord <cprecord@editra.org>                                  #
-# Copyright: (c) 2007 Cody Precord <staff@editra.org>                         #
-# Licence: wxWindows Licence                                                  #
+# Copyright: (c) 2008 Cody Precord <staff@editra.org>                         #
+# License: wxWindows License                                                  #
 ###############################################################################
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: info.py 51276 2008-01-18 10:27:07Z CJP $"
-__revision__ = "$Revision: 51276 $"
+__svnid__ = "$Id: info.py 51605 2008-02-08 15:06:51Z CJP $"
+__revision__ = "$Revision: 51605 $"
 
 
-AUTHOR = u'Cody Precord'
-VERSION = u'0.2.50'
-PROG_NAME = u'Editra'
-HOME_PAGE = u"http://editra.org"
-CONTACT_MAIL = u"staff@editra.org"
+AUTHOR = 'Cody Precord'
+VERSION = '0.2.65'
+PROG_NAME = 'Editra'
+HOME_PAGE = "http://editra.org"
+CONTACT_MAIL = "staff@editra.org"
