@@ -2,8 +2,8 @@
 # Name: prefdlg.py                                                            #
 # Purpose: UI for configuring User Profile                                    #
 # Author: Cody Precord <cprecord@editra.org>                                  #
-# Copyright: (c) 2007 Cody Precord <staff@editra.org>                         #
-# Licence: wxWindows Licence                                                  #
+# Copyright: (c) 2008 Cody Precord <staff@editra.org>                         #
+# License: wxWindows License                                                  #
 ###############################################################################
 
 """
@@ -20,8 +20,8 @@
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: prefdlg.py 51275 2008-01-18 09:53:04Z CJP $"
-__revision__ = "$Revision: 51275 $"
+__svnid__ = "$Id: prefdlg.py 51386 2008-01-26 16:13:08Z CJP $"
+__revision__ = "$Revision: 51386 $"
 
 #----------------------------------------------------------------------------#
 # Dependancies
@@ -38,6 +38,7 @@ import ed_crypt
 import updater
 import util
 import syntax.syntax as syntax
+import ed_msg
 
 #----------------------------------------------------------------------------#
 # Globals
@@ -403,7 +404,7 @@ class GeneralPanel(PrefPanelBase):
                        (pos_cb, (9, 2), (1, 3)),
                        (chkmod_cb, (10, 2), (1, 2)),
                        (locale, (12, 1), (1, 1), wx.ALIGN_CENTER_VERTICAL),
-                       (lsizer, (12, 2), (1, 3)),
+                       (lsizer, (12, 2), (1, 2)),
                        ((15, 15), (13, 0))])
         self.SetSizer(sizer)
 
@@ -514,6 +515,9 @@ class DocGenPanel(wx.Panel):
         ut_cb = wx.CheckBox(self, ed_glob.ID_PREF_TABS, 
                             _("Use Tabs Instead of Spaces"))
         ut_cb.SetValue(Profile_Get('USETABS', 'bool', False))
+        bsu_cb = wx.CheckBox(self, ed_glob.ID_PREF_UNINDENT,
+                             _("Backspace Unindents"))
+        bsu_cb.SetValue(Profile_Get('BSUNINDENT', 'bool', True))
         eol_lbl = wx.StaticText(self, label=_("Default EOL Mode") + u": ")
         eol_ch = ExChoice(self, ed_glob.ID_EOL_MODE,
                           choices=[_("Macintosh (\\r)"), _("Unix (\\n)"), 
@@ -557,18 +561,19 @@ class DocGenPanel(wx.Panel):
         sizer.Add((5, 5), (1, 0))
         sizer.Add(wx.StaticText(self, label=_("Format") + u": "), (1, 1))
         sizer.AddMany([(ut_cb, (1, 2), (1, 2)),
-                       (tabw_lbl, (2, 2), (1, 1), wx.ALIGN_CENTER_VERTICAL),
-                       (tw_ch, (2, 3), (1, 3), wx.ALIGN_CENTER_VERTICAL),
-                       (eol_lbl, (3, 2), (1, 1), wx.ALIGN_CENTER_VERTICAL),
-                       (eol_ch, (3, 3), (1, 2), wx.ALIGN_CENTER_VERTICAL),
-                       ((5, 5), (5, 0)), (view_lbl, (5, 1)),
-                       (aa_cb, (5, 2)), (seol_cb, (6, 2)), (sln_cb, (7, 2)),
-                       (sws_cb, (8, 2)), (ww_cb, (9, 2)),
-                       (font_lbl, (11, 1), (1, 1), wx.ALIGN_CENTER_VERTICAL), 
-                       (fpicker, (11, 2), (1, 3), wx.EXPAND), 
-                       (font_lbl2, (12, 1), (1, 1), wx.ALIGN_CENTER_VERTICAL),
-                       (fpicker2, (12, 2), (1, 3), wx.EXPAND),
-                       ((5, 5), (13, 0))
+                       (bsu_cb, (2, 2), (1, 1)),
+                       (tabw_lbl, (3, 2), (1, 1), wx.ALIGN_CENTER_VERTICAL),
+                       (tw_ch, (3, 3), (1, 3), wx.ALIGN_CENTER_VERTICAL),
+                       (eol_lbl, (4, 2), (1, 1), wx.ALIGN_CENTER_VERTICAL),
+                       (eol_ch, (4, 3), (1, 2), wx.ALIGN_CENTER_VERTICAL),
+                       ((5, 5), (6, 0)), (view_lbl, (6, 1)),
+                       (aa_cb, (6, 2)), (seol_cb, (7, 2)), (sln_cb, (8, 2)),
+                       (sws_cb, (9, 2)), (ww_cb, (10, 2)),
+                       (font_lbl, (12, 1), (1, 1), wx.ALIGN_CENTER_VERTICAL), 
+                       (fpicker, (12, 2), (1, 3), wx.EXPAND), 
+                       (font_lbl2, (13, 1), (1, 1), wx.ALIGN_CENTER_VERTICAL),
+                       (fpicker2, (13, 2), (1, 3), wx.EXPAND),
+                       ((5, 5), (14, 0))
                        ])
         self.SetSizer(sizer)
 
@@ -610,10 +615,10 @@ class DocGenPanel(wx.Panel):
         e_id = evt.GetId()
         e_obj = evt.GetEventObject()
         if e_id in [ed_glob.ID_PREF_TABS, ed_glob.ID_PREF_TABW,
-                    ed_glob.ID_EOL_MODE, ed_glob.ID_PREF_AALIAS,
-                    ed_glob.ID_SHOW_EOL, ed_glob.ID_SHOW_LN,
-                    ed_glob.ID_SHOW_WS, ed_glob.ID_WORD_WRAP,
-                    ed_glob.ID_PREF_AALIAS]:
+                    ed_glob.ID_PREF_UNINDENT, ed_glob.ID_EOL_MODE,
+                    ed_glob.ID_PREF_AALIAS, ed_glob.ID_SHOW_EOL,
+                    ed_glob.ID_SHOW_LN, ed_glob.ID_SHOW_WS,
+                    ed_glob.ID_WORD_WRAP, ed_glob.ID_PREF_AALIAS]:
             Profile_Set(ed_glob.ID_2_PROF[e_id], e_obj.GetValue())
             wx.CallLater(25, DoUpdates)
         else:
@@ -645,6 +650,18 @@ class DocCodePanel(wx.Panel):
         @note: Do not call this after __init__
 
         """
+        # General Section
+        gen_lbl = wx.StaticText(self, label=_("General") + u": ")
+        dlex_lbl = wx.StaticText(self, label=_("Default Lexer") + u": ")
+        dlex_ch = ExChoice(self, ed_glob.ID_PREF_DLEXER,
+                           choices=syntax.GetLexerList(),
+                           default=Profile_Get('DEFAULT_LEX',
+                                               default="Plain Text"))
+        dlex_ch.SetToolTipString(_("Default highlighing for new documents"))
+        dlex_sz = wx.BoxSizer(wx.HORIZONTAL)
+        dlex_sz.AddMany([(dlex_lbl, 0, wx.ALIGN_CENTER_VERTICAL), ((3, 3),),
+                         (dlex_ch, 0, wx.ALIGN_CENTER_VERTICAL)])
+
         # Visual Helpers Section
         vis_lbl = wx.StaticText(self, label=_("Visual Helpers") + u": ")
         br_cb = wx.CheckBox(self, ed_glob.ID_BRACKETHL, 
@@ -674,14 +691,15 @@ class DocCodePanel(wx.Panel):
 
         # Layout the controls
         sizer = wx.GridBagSizer(5, 5)
-        sizer.Add((5, 5), (1, 0))
-        sizer.Add(vis_lbl, (1, 1))
-        sizer.AddMany([(br_cb, (1, 2)), (fold_cb, (2, 2)),
-                       (edge_cb, (3, 2), (1, 1), wx.ALIGN_CENTER_VERTICAL),
-                       (edge_col, (3, 4), (1, 1), wx.ALIGN_CENTER_VERTICAL),
-                       (ind_cb, (4, 2))])
-        sizer.Add(wx.StaticText(self, label=_("Input Helpers") + u": "), (6, 1))
-        sizer.AddMany([(comp_cb, (6, 2)), (ai_cb, (7, 2)), (vi_cb, (8, 2))])
+        sizer.AddMany([((5, 5), (1, 0)),
+                       (gen_lbl, (1, 1), (1, 1), wx.ALIGN_CENTER_VERTICAL),
+                       (dlex_sz, (1, 2), (1, 3)), (vis_lbl, (3, 1)),
+                       (br_cb, (3, 2)), (fold_cb, (4, 2)),
+                       (edge_cb, (5, 2), (1, 1), wx.ALIGN_CENTER_VERTICAL),
+                       (edge_col, (5, 3), (1, 1), wx.ALIGN_CENTER_VERTICAL),
+                       (ind_cb, (7, 2))])
+        sizer.Add(wx.StaticText(self, label=_("Input Helpers") + u": "), (7, 1))
+        sizer.AddMany([(comp_cb, (8, 2)), (ai_cb, (9, 2)), (vi_cb, (10, 2))])
         self.SetSizer(sizer)
 
     def OnCheck(self, evt):
@@ -696,7 +714,8 @@ class DocCodePanel(wx.Panel):
         if e_id in [ed_glob.ID_BRACKETHL, ed_glob.ID_SHOW_EDGE,
                     ed_glob.ID_INDENT_GUIDES, ed_glob.ID_FOLDING,
                     ed_glob.ID_AUTOCOMP, ed_glob.ID_AUTOINDENT,
-                    ed_glob.ID_PREF_EDGE, ed_glob.ID_VI_MODE]:
+                    ed_glob.ID_PREF_EDGE, ed_glob.ID_VI_MODE,
+                    ed_glob.ID_PREF_DLEXER]:
             Profile_Set(ed_glob.ID_2_PROF[e_id], e_obj.GetValue())
             wx.CallLater(25, DoUpdates)
         else:
@@ -946,21 +965,7 @@ class AppearancePanel(PrefPanelBase):
                 val = (int(val), int(val))
             Profile_Set(ed_glob.ID_2_PROF[e_id], val)
             wx.GetApp().ReloadArtProvider()
-            for mainw in wx.GetApp().GetMainWindows():
-                toolbar = mainw.GetToolBar()
-                if toolbar is not None and \
-                   (toolbar.GetToolTheme() != Profile_Get('ICONS')) \
-                   or (toolbar.GetToolBitmapSize() != Profile_Get('ICON_SZ')):
-                    toolbar.ReInit()
-
-                # Update Commandbar icons
-                sbar = mainw.FindWindowById(ed_glob.ID_COMMAND_BAR)
-                if sbar:
-                    sbar.UpdateIcons()
-
-                # Update Notebook Images
-                mainw.GetNotebook().UpdateAllImages()
-
+            ed_msg.PostMessage(ed_msg.EDMSG_THEME_CHANGED, True)
         elif e_id == ed_glob.ID_PERSPECTIVES:
             Profile_Set('DEFAULT_VIEW', e_obj.GetValue())
             for main_win in wx.GetApp().GetMainWindows():
