@@ -26,8 +26,8 @@
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: profiler.py 50881 2007-12-22 02:42:52Z CJP $"
-__revision__ = "$Revision: 50881 $"
+__svnid__ = "$Id: profiler.py 51366 2008-01-25 07:57:12Z CJP $"
+__revision__ = "$Revision: 51366 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -49,8 +49,10 @@ _DEFAULTS = {
            'AUTO_COMP'  : True,             # Use Auto-comp if available
            'AUTO_INDENT': True,             # Use Auto Indent
            'BRACKETHL'  : True,             # Use bracket highlighting
+           'BSUNINDENT' : True,             # Backspace Unindents
            'CHECKMOD'   : True,             # Auto check file for file mod
            'CODE_FOLD'  : True,             # Use code folding
+           'DEFAULT_LEX': 'Plain Text',     # Default lexer for new documents
            'DEFAULT'    : False,            # No longer used I believe
            'DEFAULT_VIEW' : 'Automatic',    # Default Perspective
            'EDGE'       : 80,               # Edge guide column
@@ -81,7 +83,7 @@ _DEFAULTS = {
            'TABWIDTH'   : 8,                # Tab width
            'THEME'      : 'DEFAULT',        # For future use
            'TOOLBAR'    : True,             # Show Toolbar
-           'USETABS'    : True,             # Use tabs instead of spaces
+           'USETABS'    : False,             # Use tabs instead of spaces
            'USE_PROXY'  : False,            # Use Proxy server settings?
            'VI_EMU'     : False,            # Use Vi emulation mode 
            'WRAP'       : False,            # Use Wordwrap
