@@ -11,8 +11,8 @@
 
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: synextreg.py 50663 2007-12-12 08:32:07Z CJP $"
-__revision__ = "$Revision: 50663 $"
+__svnid__ = "$Id: synextreg.py 51489 2008-02-01 10:17:24Z CJP $"
+__revision__ = "$Revision: 51489 $"
 
 #-----------------------------------------------------------------------------#
 
@@ -79,6 +79,10 @@ ID_LANG_DOT = _NewId()
 LANG_DOT = u'DOT'
 ID_LANG_EDJE = _NewId()
 LANG_EDJE = u'Edje'
+ID_LANG_FERITE = _NewId()
+LANG_FERITE = u'Ferite'
+ID_LANG_HAXE = _NewId()
+LANG_HAXE = u'HaXe'
 ID_LANG_JAVA = _NewId()
 LANG_JAVA = u'Java'
 ID_LANG_PIKE = _NewId()
@@ -260,11 +264,13 @@ EXT_MAP = {
            'e'                  : LANG_EIFFEL,
            'erl'                : LANG_ERLANG,
            'ess'                : LANG_ESS,
-           'prg'                : LANG_FLAGSHIP,
            'f for'              : LANG_F77,
            'f90 f95 f2k fpp'    : LANG_F95,
+           'prg'                : LANG_FLAGSHIP,
+           'fe'                 : LANG_FERITE,
            'gc gui'             : LANG_GUI4CLI,
            'hs'                 : LANG_HASKELL,
+           'hx'                 : LANG_HAXE,
            'htm html shtm shtml xhtml' : LANG_HTML,
            'iss'                : LANG_INNO,
            'java'               : LANG_JAVA,
@@ -280,7 +286,7 @@ EXT_MAP = {
            'm matlab'           : LANG_MATLAB,
            'mssql'              : LANG_MSSQL,
            'nasm'               : LANG_NASM,
-           'nsi'                : LANG_NSIS,
+           'nsi nsh'            : LANG_NSIS,
            'oct octave'         : LANG_OCTAVE,
            'dfm dpk dpr inc p pas pp' : LANG_PASCAL,
            'cgi pl pm pod'      : LANG_PERL,
@@ -303,7 +309,6 @@ EXT_MAP = {
           }
 
 
-
 #-----------------------------------------------------------------------------#
 
 class ExtensionRegister(dict):
