@@ -34,20 +34,22 @@
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__cvsid__ = "$Id: updater.py 49397 2007-10-24 14:17:58Z CJP $"
-__revision__ = "$Revision: 49397 $"
+__cvsid__ = "$Id: updater.py 51219 2008-01-15 07:51:16Z CJP $"
+__revision__ = "$Revision: 51219 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
 import os
+import stat
 import re
-import urllib
+import urllib2
 import wx
 import wx.lib.delayedresult as delayedresult
 import ed_glob
 import ed_event
-from profiler import CalcVersionValue
+from profiler import CalcVersionValue, Profile_Get
 import util
+
 #--------------------------------------------------------------------------#
 # Globals
 DL_REQUEST = ed_glob.HOME_PAGE + "/?page=download&dist=%s"
@@ -67,6 +69,29 @@ class UpdateService(object):
         self._abort = False
         self._progress = (0, 100)
 
+    def __GetUrlHandle(self, url):
+        """Gets a file handle for the given url. The caller is responsible for
+        closing the handle.
+        @requires: network conection
+        @param url: url to get page from
+        @return: all text from the given url
+
+        """
+        h_file = None
+        try:
+            if Profile_Get('USE_PROXY', default=False):
+                proxy_set = Profile_Get('PROXY_SETTINGS',
+                                        default=dict(uname='', url='',
+                                                     port='80', passwd=''))
+
+                proxy = util.GetProxyOpener(proxy_set)
+                h_file = proxy.open(url)
+            else:
+                h_file = urllib2.urlopen(url)
+
+        finally:
+            return h_file
+
     def Abort(self):
         """Cancel any pending or in progress actions.
         @postcondition: any download actions will be aborted
@@ -98,6 +123,7 @@ class UpdateService(object):
             url = url[0]
         else:
             url = wx.EmptyString
+
         return url.strip()
 
     def GetCurrFileName(self):
@@ -122,6 +148,8 @@ class UpdateService(object):
         if len(found):
             return found[0] # Should be the first/only match found
         else:
+            util.Log("[updater][warn] UpdateService.GetCurrentVersionStr "
+                     "Failed to get version info.")
             return _("Unable to retrieve version info")
 
     def GetFileSize(self, url):
@@ -132,7 +160,7 @@ class UpdateService(object):
         """
         size = 0
         try:
-            dl_file = urllib.urlopen(url)
+            dl_file = self.__GetUrlHandle(url)
             info = dl_file.info()
             size = int(info['Content-Length'])
             dl_file.close()
@@ -148,7 +176,7 @@ class UpdateService(object):
         """
         text = u''
         try:
-            h_file = urllib.urlopen(url)
+            h_file = self.__GetUrlHandle(url)
             text = h_file.read()
             h_file.close()
         finally:
@@ -183,18 +211,22 @@ class UpdateService(object):
             blk_sz = 4096
             read = 0
             try:
-                webfile = urllib.urlopen(dl_path)
+                # Download the file in chunks so it can be aborted if need be
+                # inbetween reads.
+                webfile = self.__GetUrlHandle(dl_path)
                 fsize = int(webfile.info()['Content-Length'])
                 locfile = open(dl_to, 'wb')
                 while read < fsize and not self._abort:
                     locfile.write(webfile.read(blk_sz))
                     read += blk_sz
                     self.UpdaterHook(int(read/blk_sz), blk_sz, fsize)
+
                 locfile.close()
                 webfile.close()
             finally:
                 self._abort = False
-                if os.path.exists(dl_to) and os.stat(dl_to)[6] == fsize:
+                if os.path.exists(dl_to) and \
+                   os.stat(dl_to)[stat.ST_SIZE] == fsize:
                     return True
                 else:
                     return False
@@ -253,7 +285,7 @@ class UpdateProgress(wx.Gauge, UpdateService):
 
         """
         if self._timer.IsRunning():
-            self.LOG("[updateprog][info] Stopped timer on deletion")
+            self.LOG("[updater][info]UpdateProgress: __del__, stopped timer")
             self._timer.Stop()
 
     def Abort(self):
@@ -261,7 +293,7 @@ class UpdateProgress(wx.Gauge, UpdateService):
         @postcondition: any download actions in the L{UpdateService} are aborted
 
         """
-        self.LOG("[updateprog][info] Aborting action, stopping progress bar")
+        self.LOG("[updater][info] UpdateProgress: Download aborted")
         UpdateService.Abort(self)
         if self._timer.IsRunning():
             self._timer.Stop()
@@ -295,7 +327,7 @@ class UpdateProgress(wx.Gauge, UpdateService):
         @keyword dl_loc: location to download file to
         
         """
-        self.LOG("[updateprog][evt] Attempting to download updates...")
+        self.LOG("[updater][info] UpdateProgress: Download Starting...")
         if dl_loc == wx.EmptyString:
             dl_loc = wx.GetHomeDir() + util.GetPathChar()
             if os.path.exists(dl_loc + u"Desktop"):
@@ -402,7 +434,7 @@ class UpdateProgress(wx.Gauge, UpdateService):
 
         """
         if not self._timer.IsRunning():
-            self.LOG('[updateprog][evt] Starting Clock')
+            self.LOG('[updater][info] UpdateProgress: Starting Timer')
             self.Enable()
             self._timer.Start(msec)
         else:
@@ -414,7 +446,7 @@ class UpdateProgress(wx.Gauge, UpdateService):
 
         """
         if self._timer.IsRunning():
-            self.LOG('[updateprog][evt] Stopping Clock')
+            self.LOG('[updater][info] UpdateProgress: Stopping Clock')
             self._timer.Stop()
             self._mode = 0
         else:
@@ -442,7 +474,7 @@ class UpdateProgress(wx.Gauge, UpdateService):
         jid = delayedResult.getJobID()
 
         try:
-            self.LOG("[updateprog][info] Worker thread exited. ID = %d" % jid)
+            self.LOG("[updater][info] UpdateProgress: Worker thread exited. ID = %d" % jid)
             self._checking = self._downloading = False # Work has finished
         except wx.PyDeadObjectError:
             return
@@ -458,8 +490,8 @@ class UpdateProgress(wx.Gauge, UpdateService):
             else:
                 pass
         except (OSError, IOError), msg:
-            self.LOG("[updateprog][err] Error on thread exit")
-            self.LOG("[updateprog][err] %s" % str(msg))
+            self.LOG("[updater][err] UpdateProgress: Error on thread exit")
+            self.LOG("[updater][err] UpdateProgress: error = %s" % str(msg))
 
     def _UpdatesCheckThread(self):
         """Sets internal status value to the return value from calling
@@ -471,11 +503,11 @@ class UpdateProgress(wx.Gauge, UpdateService):
         @return: whether updates are available or not
         
         """
-        self.LOG("[updateprog][evt] Checking for updates")
+        self.LOG("[updater][info] UpdateProgress: Checking for updates")
         self._checking = True
         ret = self.GetCurrentVersionStr()
         self._status = ret
-        self.LOG("[updateprog][evt] Update Check Finished: result = " + ret)
+        self.LOG("[updater][info] UpdateProgress: Check Finished: result = " + ret)
         if ret[0].isdigit() and \
            CalcVersionValue(ret) > CalcVersionValue(ed_glob.VERSION):
             ret = True
@@ -550,7 +582,7 @@ class DownloadDialog(wx.Frame):
         self.SetInitialSize()
 
         self.SetStatusWidths([-1, 100])
-        self.SetStatusText(_("Downloading..."), self.SB_INFO)
+        self.SetStatusText(_("Downloading") + u"...", self.SB_INFO)
 
         #---- Bind Events ----#
         self.Bind(wx.EVT_BUTTON, self.OnButton)
@@ -563,7 +595,7 @@ class DownloadDialog(wx.Frame):
 
         """
         if self._timer.IsRunning():
-            self.LOG('[update-dlg][info] Stopping timer on deletion')
+            self.LOG('[updater][info] DownloadDialog: __del__ Timer Stopped')
             self._timer.Stop()
 
     def CalcDownRate(self):
@@ -588,7 +620,7 @@ class DownloadDialog(wx.Frame):
         """
         e_id = evt.GetId()
         if e_id == wx.ID_CANCEL:
-            self.LOG("[downloaddlg][evt] Cancel pressed, aborting download")
+            self.LOG("[updater][evt] DownloadDialog: Cancel pressed")
             self._progress.Abort()
             self._cancel_bt.Disable()
             self.SetStatusText(_("Canceled"), self.SB_INFO)
@@ -600,7 +632,7 @@ class DownloadDialog(wx.Frame):
         @param evt: event that called this handler
 
         """
-        self.LOG("[download-dlg] [evt] Closing Download Dialog")
+        self.LOG("[updater][evt] DownloadDialog: Closing Download Dialog")
         self._progress.Abort()
         # Wait till thread has halted before exiting
         while self._progress.IsDownloading():
@@ -619,19 +651,19 @@ class DownloadDialog(wx.Frame):
             self._proghist.append(prog[0])
             speed = self.CalcDownRate()
             if self._progress.IsDownloading():
-                self.SetStatusText(_("Downloaded: ") + str(prog[0]) + \
+                self.SetStatusText(_("Downloaded") + ": " + str(prog[0]) + \
                                     u"/" + str(prog[1]) + u" | " + \
                                     _("Rate: %.2f Kb/s") % speed, 
                                     self.SB_DOWNLOADED)
             else:
-                self.LOG("[download-dlg][evt] Download finished")
-                self.SetStatusText(_("Downloaded: ") + str(prog[0]) + \
+                self.LOG("[updater][evt] DownloadDialog:: Download finished")
+                self.SetStatusText(_("Downloaded") + ": " + str(prog[0]) + \
                                     u"/" + str(prog[1]), self.SB_DOWNLOADED)
                 if self._progress.GetDownloadResult():
-                    self.LOG("[download-dlg][info] Download Successful")
+                    self.LOG("[updater][info] DownloadDialog: Download Successful")
                     self.SetStatusText(_("Finished"), self.SB_INFO)
                 else:
-                    self.LOG("[download-dlg][info] Download Failed")
+                    self.LOG("[updater][info] DownloadDialog: Download Failed")
                     self.SetStatusText(_("Failed"), self.SB_INFO)
                 self._progress.Enable()
                 self._progress.SetValue(self._progress.GetProgress()[0])
