@@ -12,8 +12,8 @@ Test file for testing the PlateButton control
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: PlateButtonDemo.py 51067 2008-01-07 09:01:14Z CJP $"
-__revision__ = "$Revision: 51067 $"
+__svnid__ = "$Id: PlateButtonDemo.py 51469 2008-01-31 07:45:45Z CJP $"
+__revision__ = "$Revision: 51469 $"
 
 #-----------------------------------------------------------------------------#
 # Imports
@@ -65,7 +65,7 @@ class TestPanel(wx.Panel):
         """Puts a set of controls in the panel
         @param panel: panel to layout
         @param label: panels title
-        @param exstyle: Set the PB_STYLE_NOBG or not
+        @keyword exstyle: Set the PB_STYLE_NOBG or not
 
         """
         # Bitmaps (32x32) and (16x16)
